// src/app/dashboard/design/page.tsx
'use client'
import { useState } from 'react'
import { 
  Palette, 
  Sparkles, 
  Clock, 
  Search,
  Filter,
  Download,
  Share2,
  PlusCircle
} from 'lucide-react'
import { useTheme } from '@/contexts/themecontext'

// Mock data for previously generated images
const recentDesigns = [
  {
    id: 1,
    prompt: "Minimalist social media post for coffee shop",
    date: "2 hours ago",
    imageUrl: "https://picsum.photos/200/300",
    tags: ["social media", "minimalist"]
  },
  {
    id: 2,
    prompt: "Instagram story with modern typography",
    date: "5 hours ago",
    imageUrl: "https://picsum.photos/250/300",
    tags: ["instagram", "typography"]
  },
  // Add more mock designs
]

export default function DesignPage() {
  const [prompt, setPrompt] = useState("")
  const [isGenerating, setIsGenerating] = useState(false)
  const { theme } = useTheme()

  const handleGenerate = () => {
    setIsGenerating(true)
    // Mock generation process
    setTimeout(() => {
      setIsGenerating(false)
    }, 2000)
  }

  return (
    <div className="p-6">
      {/* Header */}
      <div className="mb-8">
        <h1 className={`text-4xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-2 flex items-center`}>
          <Palette className="w-8 h-8 mr-3 text-purple-500" />
          Design
        </h1>
        <p className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} text-lg`}>Generate and manage your AI-powered designs</p>
      </div>

      {/* Generation Section */}
      <div className={`${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg p-6 mb-8 shadow-lg`}>
        <div className="max-w-3xl mx-auto">
          <h2 className={`text-xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-4`}>Create New Design</h2>
          
          {/* Prompt Input */}
          <div className="mb-6">
            <div className="relative">
              <input
                type="text"
                placeholder="Describe your design idea..."
                value={prompt}
                onChange={(e) => setPrompt(e.target.value)}
                className={`w-full ${theme === 'dark' ? 'bg-gray-700' : 'bg-gray-100'} rounded-lg pl-4 pr-36 py-3 ${theme === 'dark' ? 'text-white' : 'text-gray-900'} ${theme === 'dark' ? 'placeholder-gray-400' : 'placeholder-gray-500'} focus:ring-2 focus:ring-purple-500`}
              />
              <button
                onClick={handleGenerate}
                disabled={isGenerating || !prompt}
                className="absolute right-2 top-1/2 -translate-y-1/2 bg-purple-500 hover:bg-purple-600 disabled:bg-gray-600 text-white px-4 py-1.5 rounded-md flex items-center transition-colors"
              >
                <Sparkles className="w-4 h-4 mr-2" />
                {isGenerating ? 'Generating...' : 'Generate'}
              </button>
            </div>
            
            {/* Quick Suggestions */}
            <div className="flex gap-2 mt-3">
              {['Social Media Post', 'Story Template', 'Advertisement'].map((suggestion) => (
                <button 
                  key={suggestion}
                  className={`px-3 py-1.5 ${theme === 'dark' ? 'bg-gray-700 hover:bg-gray-600' : 'bg-gray-100 hover:bg-gray-200'} rounded-full text-sm ${theme === 'dark' ? 'text-gray-300' : 'text-gray-600'} transition-colors`}
                >
                  {suggestion}
                </button>
              ))}
            </div>
          </div>
        </div>
      </div>

      {/* Recent Designs */}
      <div>
        <div className="flex items-center justify-between mb-6">
          <h2 className={`text-xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} flex items-center`}>
            <Clock className="w-5 h-5 mr-2" />
            Recent Designs
          </h2>
          
          <div className="flex items-center gap-4">
            {/* Search */}
            <div className="relative">
              <Search className={`w-4 h-4 absolute left-3 top-1/2 -translate-y-1/2 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
              <input
                type="text"
                placeholder="Search designs..."
                className={`${theme === 'dark' ? 'bg-gray-700' : 'bg-gray-100'} rounded-md pl-9 pr-4 py-2 text-sm ${theme === 'dark' ? 'text-white' : 'text-gray-900'} ${theme === 'dark' ? 'placeholder-gray-400' : 'placeholder-gray-500'} focus:ring-2 focus:ring-purple-500`}
              />
            </div>
            
            {/* Filter */}
            <button className={`${theme === 'dark' ? 'bg-gray-700 hover:bg-gray-600' : 'bg-gray-100 hover:bg-gray-200'} p-2 rounded-md transition-colors`}>
              <Filter className={`w-4 h-4 ${theme === 'dark' ? 'text-gray-300' : 'text-gray-600'}`} />
            </button>
          </div>
        </div>

        {/* Design Grid */}
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
          {/* New Design Card */}
          <button className={`aspect-video ${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg border-2 border-dashed ${theme === 'dark' ? 'border-gray-700' : 'border-gray-200'} hover:border-purple-500 flex items-center justify-center group transition-colors shadow-lg`}>
            <div className="text-center">
              <PlusCircle className="w-8 h-8 mb-2 text-gray-500 group-hover:text-purple-500 mx-auto transition-colors" />
              <span className="text-gray-500 group-hover:text-purple-500 transition-colors">Create New Design</span>
            </div>
          </button>

          {/* Recent Designs */}
          {recentDesigns.map((design) => (
            <div key={design.id} className={`group relative ${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} rounded-lg overflow-hidden shadow-lg`}>
              {/* Image */}
              <img
                src={design.imageUrl}
                alt={design.prompt}
                className="w-full aspect-video object-cover"
              />
              
              {/* Overlay */}
              <div className="absolute inset-0 bg-gradient-to-t from-black/60 via-black/0 to-black/0 opacity-0 group-hover:opacity-100 transition-opacity">
                <div className="absolute bottom-0 left-0 right-0 p-4">
                  <p className="text-white text-sm mb-2">{design.prompt}</p>
                  <div className="flex items-center justify-between">
                    <span className="text-gray-300 text-xs">{design.date}</span>
                    <div className="flex gap-2">
                      <button className={`p-1.5 ${theme === 'dark' ? 'bg-gray-800/80 hover:bg-gray-700' : 'bg-white/80 hover:bg-gray-100'} rounded-md transition-colors`}>
                        <Download className={`w-4 h-4 ${theme === 'dark' ? 'text-gray-300' : 'text-gray-600'}`} />
                      </button>
                      <button className={`p-1.5 ${theme === 'dark' ? 'bg-gray-800/80 hover:bg-gray-700' : 'bg-white/80 hover:bg-gray-100'} rounded-md transition-colors`}>
                        <Share2 className={`w-4 h-4 ${theme === 'dark' ? 'text-gray-300' : 'text-gray-600'}`} />
                      </button>
                    </div>
                  </div>
                </div>
              </div>

              {/* Tags */}
              <div className="absolute top-2 left-2 flex gap-2">
                {design.tags.map((tag, index) => (
                  <span 
                    key={index}
                    className="px-2 py-1 bg-black/50 rounded-full text-white text-xs"
                  >
                    {tag}
                  </span>
                ))}
              </div>
            </div>
          ))}
        </div>
      </div>
    </div>
  )
}