'use client';

import { Suspense } from 'react'
import { useEffect, useState } from 'react';
import { useRouter, useSearchParams } from 'next/navigation';
import { ArrowRight, Moon, Sun } from 'lucide-react';
import { validateInviteToken } from '@/lib/api/core'
import Image from 'next/image'
import byom from '@/app/assets/byom.png'
import { useTheme } from '@/contexts/themecontext'

function InvitContent() {
  const router = useRouter();
  const searchParams = useSearchParams();
  const token = searchParams.get('token');
  const { theme, toggleTheme } = useTheme();
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);
  const [isValid, setIsValid] = useState(false);
  const [email, setEmail] = useState<string>('');

  useEffect(() => {
    const validateToken = async () => {
      if (!token) {
        setError('Aucun jeton d\'invitation fourni');
        setIsLoading(false);
        return;
      }

      try {
        const response = await validateInviteToken(token);
        setIsValid(true);
        if (response.email) {
          setEmail(response.email);
        }
      } catch (error) {
        setError(error instanceof Error ? error.message : 'Échec de la validation de l\'invitation');
      } finally {
        setIsLoading(false);
      }
    };

    validateToken();
  }, [token]);

  const handleContinueToRegister = () => {
    router.push(`/register/member?token=${token}&email=${email}`);
  };

  const handleDecline = () => {
    router.push('/');
  };

  if (isLoading) {
    return (
      <div className={`min-h-screen ${theme === 'dark' ? 'bg-gray-900' : 'bg-gray-50'} flex flex-col items-center justify-center relative p-4 transition-colors duration-300`}>
        <div className={`w-full max-w-md ${theme === 'dark' ? 'bg-gray-800/50 backdrop-blur-xl' : 'bg-white/80 backdrop-blur-xl'} rounded-2xl shadow-2xl p-8 transition-all duration-300`}>
          <div className="flex justify-center">
            <div className="w-8 h-8 border-2 border-blue-500 border-t-transparent rounded-full animate-spin" />
          </div>
        </div>
      </div>
    );
  }

  return (
    <div className={`min-h-screen ${theme === 'dark' ? 'bg-gray-900' : 'bg-gray-50'} flex flex-col items-center justify-center relative p-4 transition-colors duration-300`}>
      <button
        onClick={toggleTheme}
        className={`absolute top-4 right-4 p-3 rounded-xl ${
          theme === 'dark' 
            ? 'bg-gray-800 hover:bg-gray-700' 
            : 'bg-white hover:bg-gray-100'
        } transition-all duration-300 shadow-lg hover:shadow-xl transform hover:scale-105`}
        aria-label="Toggle theme"
      >
        {theme === 'dark' ? (
          <Sun className="w-5 h-5 text-yellow-500" />
        ) : (
          <Moon className="w-5 h-5 text-gray-600" />
        )}
      </button>

      <div className={`w-full max-w-md ${theme === 'dark' ? 'bg-gray-800/50 backdrop-blur-xl' : 'bg-white/80 backdrop-blur-xl'} rounded-2xl shadow-2xl p-8 transition-all duration-300`}>
        <div className="flex justify-center mb-8 transform hover:scale-105 transition-transform duration-300">
          <Image 
            src={byom} 
            alt="BYOM" 
            width={200} 
            className={`${theme === 'dark' ? '' : 'invert'} transition-all duration-300 drop-shadow-lg`}
          />
        </div>
        
        <div className="text-center mb-8">
          <h1 className={`text-3xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-3 tracking-tight`}>
            Invitation à l&apos;espace de travail
          </h1>
          {email && (
            <p className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} text-lg`}>
              pour <span className={theme === 'dark' ? 'text-white' : 'text-gray-900'}>{email}</span>
            </p>
          )}
        </div>

        <div className="space-y-6">
          {error ? (
            <div className="space-y-4">
              <div className={`p-4 rounded-xl ${theme === 'dark' ? 'bg-red-900/50 text-red-300' : 'bg-red-100 text-red-600'} backdrop-blur-xl`}>
                {error}
              </div>
              <button 
                className="w-full flex items-center justify-center px-4 py-3 rounded-xl bg-blue-500 text-white font-medium hover:bg-blue-600 hover:shadow-lg hover:-translate-y-0.5 transition-all duration-300"
                onClick={() => router.push('/')}
              >
                Retour à l&apos;accueil
              </button>
            </div>
          ) : isValid ? (
            <div className="space-y-6">
              <p className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} text-base`}>
                Vous devez créer un compte pour rejoindre cet espace de travail. Cliquez sur continuer pour configurer votre compte.
              </p>
              <div className="flex gap-3">
                <button
                  className="flex-1 flex items-center justify-center px-4 py-3 rounded-xl bg-blue-500 text-white font-medium hover:bg-blue-600 hover:shadow-lg hover:-translate-y-0.5 transition-all duration-300 disabled:opacity-70 disabled:cursor-not-allowed disabled:hover:translate-y-0"
                  onClick={handleContinueToRegister}
                  disabled={isLoading}
                >
                  {isLoading ? (
                    <div className="w-5 h-5 border-2 border-white border-t-transparent rounded-full animate-spin" />
                  ) : (
                    <>
                      <span>Continuer</span>
                      <ArrowRight className="w-5 h-5 ml-2 transform group-hover:translate-x-1 transition-transform duration-300" />
                    </>
                  )}
                </button>
                <button
                  className={`flex-1 px-4 py-3 rounded-xl font-medium transition-all duration-300 disabled:opacity-70 disabled:cursor-not-allowed ${
                    theme === 'dark'
                      ? 'bg-gray-700 text-white hover:bg-gray-600'
                      : 'bg-gray-200 text-gray-900 hover:bg-gray-300'
                  }`}
                  onClick={handleDecline}
                  disabled={isLoading}
                >
                  Refuser
                </button>
              </div>
            </div>
          ) : (
            <div className={`p-4 rounded-xl ${theme === 'dark' ? 'bg-yellow-900/50 text-yellow-300' : 'bg-yellow-100 text-yellow-600'} backdrop-blur-xl`}>
              Ce lien d&apos;invitation semble invalide ou a expiré.
            </div>
          )}
        </div>
      </div>
    </div>
  );
}

export default function InvitePage() {
  return (
    <Suspense fallback={<div>Loading...</div>}>
      <InvitContent />
    </Suspense>
  )
}