'use client';

import { Suspense } from 'react'
import { useState } from 'react';
import { useRouter, useSearchParams } from 'next/navigation';
import { Eye, EyeOff, ArrowRight, Sun, Moon, Mail, Lock } from 'lucide-react';
import Image from 'next/image';
import byom from '@/app/assets/byom.png';
import { useTheme } from '@/contexts/themecontext';
import Link from 'next/link';
import { login } from '@/lib/api/core';

function LoginContent() {
  const router = useRouter();
  const searchParams = useSearchParams();
  const { theme, toggleTheme } = useTheme();
  const [showPassword, setShowPassword] = useState(false);
  const [formData, setFormData] = useState({
    email: searchParams.get('email') || '',
    password: ''
  });
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);

  const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setFormData(prev => ({
      ...prev,
      [e.target.name]: e.target.value
    }));
  };

  const handleLogin = async (e: React.FormEvent) => {
    e.preventDefault();
    setError(null);
    setIsLoading(true);

    try {
      const token = await login(formData);

      if (!token || !token.token) {
        throw new Error('Token is missing from response');
      }
      
      localStorage.removeItem('token');
      localStorage.setItem('token', token.token);
      router.push('/dashboard');
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Login failed');
    } finally {
      setIsLoading(false);
    }
  };

  return (
    <div className={`min-h-screen ${theme === 'dark' ? 'bg-gray-900' : 'bg-gray-50'} flex flex-col items-center justify-center relative p-4 transition-colors duration-300`}>
      {/* Theme Toggle */}
      <button
        onClick={toggleTheme}
        className={`absolute top-4 right-4 p-3 rounded-xl ${
          theme === 'dark' 
            ? 'bg-gray-800 hover:bg-gray-700' 
            : 'bg-white hover:bg-gray-100'
        } transition-all duration-300 shadow-lg hover:shadow-xl transform hover:scale-105`}
        aria-label="Toggle theme"
      >
        {theme === 'dark' ? (
          <Sun className="w-5 h-5 text-yellow-500" />
        ) : (
          <Moon className="w-5 h-5 text-gray-600" />
        )}
      </button>

      <div className={`w-full max-w-md ${theme === 'dark' ? 'bg-gray-800/50 backdrop-blur-xl' : 'bg-white/80 backdrop-blur-xl'} rounded-2xl shadow-2xl p-8 transition-all duration-300`}>
        {/* Logo */}
        <div className="flex justify-center mb-8 transform hover:scale-105 transition-transform duration-300">
          <Image 
            src={byom} 
            alt="BYOM" 
            width={200} 
            className={`${theme === 'dark' ? '' : 'invert'} transition-all duration-300 drop-shadow-lg`}
          />
        </div>

        {/* Welcome Text */}
        <div className="text-center mb-8">
          <h1 className={`text-3xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-3 tracking-tight`}>
            Bienvenue
          </h1>
          <p className={`${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'} text-lg`}>
            Connectez-vous pour accéder à votre espace
          </p>
        </div>

        {/* Login Form */}
        <form onSubmit={handleLogin} className="space-y-6">
          {error && (
            <div className={`p-4 rounded-xl ${theme === 'dark' ? 'bg-red-900/50 text-red-300' : 'bg-red-100 text-red-600'} backdrop-blur-xl`}>
              {error}
            </div>
          )}

          <div className="space-y-4">
            <div>
              <label htmlFor="email" className={`block text-sm font-medium ${theme === 'dark' ? 'text-gray-300' : 'text-gray-700'} mb-2`}>
                Adresse email
              </label>
              <div className="relative">
                <Mail className={`absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
                <input
                  id="email"
                  name="email"
                  type="email"
                  value={formData.email}
                  onChange={handleChange}
                  className={`w-full pl-11 pr-4 py-3 rounded-xl ${
                    theme === 'dark' 
                      ? 'bg-gray-700/50 text-white placeholder-gray-400 focus:ring-blue-500' 
                      : 'bg-gray-50/50 text-gray-900 placeholder-gray-500 focus:ring-blue-500'
                  } border-none focus:ring-2 transition-all duration-300`}
                  placeholder="vous@exemple.com"
                  required
                />
              </div>
            </div>

            <div>
              <label htmlFor="password" className={`block text-sm font-medium ${theme === 'dark' ? 'text-gray-300' : 'text-gray-700'} mb-2`}>
                Mot de passe
              </label>
              <div className="relative">
                <Lock className={`absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
                <input
                  id="password"
                  name="password"
                  type={showPassword ? 'text' : 'password'}
                  value={formData.password}
                  onChange={handleChange}
                  className={`w-full pl-11 pr-11 py-3 rounded-xl ${
                    theme === 'dark' 
                      ? 'bg-gray-700/50 text-white placeholder-gray-400 focus:ring-blue-500' 
                      : 'bg-gray-50/50 text-gray-900 placeholder-gray-500 focus:ring-blue-500'
                  } border-none focus:ring-2 transition-all duration-300`}
                  placeholder="••••••••"
                  required
                />
                <button
                  type="button"
                  onClick={() => setShowPassword(!showPassword)}
                  className={`absolute right-3 top-1/2 -translate-y-1/2 p-1 rounded-lg ${
                    theme === 'dark' ? 'text-gray-400 hover:text-gray-300 hover:bg-gray-600/50' : 'text-gray-600 hover:text-gray-900 hover:bg-gray-200/50'
                  } transition-all duration-300`}
                >
                  {showPassword ? <EyeOff className="w-5 h-5" /> : <Eye className="w-5 h-5" />}
                </button>
              </div>
            </div>
          </div>

          <div className="flex items-center justify-between pt-2">
            <div className="flex items-center">
              <input
                id="remember"
                type="checkbox"
                className="h-4 w-4 rounded-md border-gray-300 text-blue-500 focus:ring-blue-500 transition-colors duration-300"
              />
              <label htmlFor="remember" className={`ml-2 block text-sm ${theme === 'dark' ? 'text-gray-300' : 'text-gray-700'}`}>
                Se souvenir de moi
              </label>
            </div>
            <Link
              href="/forgot-password"
              className="text-sm font-medium text-blue-500 hover:text-blue-400 transition-colors duration-300"
            >
              Mot de passe oublié ?
            </Link>
          </div>

          <button
            type="submit"
            disabled={isLoading}
            className={`w-full flex items-center justify-center px-4 py-3 rounded-xl bg-blue-500 text-white font-medium 
              ${isLoading ? 'opacity-70 cursor-not-allowed' : 'hover:bg-blue-600 hover:shadow-lg hover:-translate-y-0.5'} 
              transition-all duration-300 mt-6`}
          >
            {isLoading ? (
              <div className="w-5 h-5 border-2 border-white border-t-transparent rounded-full animate-spin" />
            ) : (
              <>
                <span>Se connecter</span>
                <ArrowRight className="w-5 h-5 ml-2 transform group-hover:translate-x-1 transition-transform duration-300" />
              </>
            )}
          </button>
        </form>

        {/* Register Link */}
        <p className={`mt-8 text-center text-sm ${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'}`}>
          Pas encore de compte ?{' '}
          <Link
            href="/register"
            className="font-medium text-blue-500 hover:text-blue-400 transition-colors duration-300 hover:underline"
          >
            Créer un compte
          </Link>
        </p>
      </div>
    </div>
  );
}

export default function LoginPage() {
  return (
    <Suspense fallback={<div>Loading...</div>}>
      <LoginContent />
    </Suspense>
  )
}