'use client';

import { useState } from 'react';
import { useRouter } from 'next/navigation';
import { Moon, Sun } from 'lucide-react';
import { useTheme } from '@/contexts/themecontext';
import { createWorkspace, applyUserToWorkspace } from '@/lib/api/core';

interface SetupData {
  name: string;
}

export default function SetupPage() {
  const router = useRouter();
  const { theme, toggleTheme } = useTheme();
  const [currentStep] = useState(1);
  const [data, setData] = useState<SetupData>({
    name: '',
  });
  const [isLoading, setIsLoading] = useState(false);
  const [, setError] = useState<string | null>(null);

  const handleSubmit = async () => {
    setIsLoading(true);
    setError(null);

    try {
      const workspace = await createWorkspace(data);

      console.log('Workspace:', workspace);

      const userData = {
        workspace_id: workspace.id, 
        role: 'owner'
      }

      await applyUserToWorkspace(userData);


      router.push('/dashboard');
    } catch (err) {
      setError(err instanceof Error ? err.message : 'La configuration a échoué');
    } finally {
      setIsLoading(false);
    }
  };

  return (
    <div className={`min-h-screen ${theme === 'dark' ? 'bg-gray-900' : 'bg-gray-50'} flex flex-col justify-center py-12 px-4 sm:px-6 lg:px-8 relative`}>
      {/* Theme Toggle Button */}
      <button
        onClick={toggleTheme}
        className={`absolute top-4 right-4 p-2 rounded-lg ${
          theme === 'dark' 
            ? 'bg-gray-800 hover:bg-gray-700' 
            : 'bg-white hover:bg-gray-100'
        } transition-colors shadow-lg`}
        aria-label="Toggle theme"
      >
        {theme === 'dark' ? (
          <Sun className="w-5 h-5 text-yellow-500" />
        ) : (
          <Moon className="w-5 h-5 text-gray-600" />
        )}
      </button>

      <div className="sm:mx-auto sm:w-full sm:max-w-2xl">
        {/* Progress Steps */}
        <div className="flex justify-center mb-8">
          <div className="flex items-center space-x-4">
            <div className={`w-8 h-8 rounded-full flex items-center justify-center text-white ${
              currentStep >= 1 ? 'bg-blue-500' : theme === 'dark' ? 'bg-gray-700' : 'bg-gray-300'
            }`}>
              1
            </div>
            <div className={`w-16 h-1 ${currentStep >= 2 ? 'bg-blue-500' : theme === 'dark' ? 'bg-gray-700' : 'bg-gray-300'}`} />
            <div className={`w-8 h-8 rounded-full flex items-center justify-center text-white ${
              currentStep >= 2 ? 'bg-blue-500' : theme === 'dark' ? 'bg-gray-700' : 'bg-gray-300'
            }`}>
              2
            </div>
          </div>
        </div>

        {/* Step 1: Workspace Name */}
        {currentStep === 1 && (
          <div className={`${theme === 'dark' ? 'bg-gray-800' : 'bg-white'} py-8 px-4 shadow sm:rounded-lg sm:px-10`}>
            <h2 className={`text-2xl font-bold ${theme === 'dark' ? 'text-white' : 'text-gray-900'} mb-6`}>
              Nommez votre espace de travail
            </h2>
            <div className="space-y-6">
              <div>
                <label htmlFor="workspace-name" className={`block text-sm font-medium ${theme === 'dark' ? 'text-gray-200' : 'text-gray-700'}`}>
                  Nom de l&apos;espace de travail
                </label>
                <div className="mt-1">
                  <input
                    type="text"
                    id="workspace-name"
                    value={data.name}
                    onChange={(e) => setData(prev => ({ ...prev, name: e.target.value }))}
                    className={`block w-full appearance-none rounded-md border-0 ${
                      theme === 'dark'
                        ? 'bg-gray-700 text-white placeholder-gray-400'
                        : 'bg-gray-50 text-gray-900 placeholder-gray-500'
                    } px-3 py-2 focus:border-blue-500 focus:outline-none focus:ring-2 focus:ring-blue-500 sm:text-sm`}
                    placeholder="Entrez le nom de l'espace de travail"
                    required
                  />
                </div>
              </div>

              <div className="flex justify-end">
                <button
                  onClick={handleSubmit}
                  disabled={!data.name.trim() || isLoading}
                  className="flex items-center justify-center rounded-md bg-blue-500 px-4 py-2 text-sm font-semibold text-white shadow-sm hover:bg-blue-400 focus-visible:outline focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-blue-500 disabled:opacity-50 disabled:cursor-not-allowed"
                >
                  {isLoading ? (
                    <div className="w-5 h-5 border-2 border-white border-t-transparent rounded-full animate-spin" />
                  ) : (
                    'Terminer la configuration'
                  )}
                </button>
              </div>
            </div>
          </div>
        )}
      </div>
    </div>
  );
}
