'use client';

import { useState } from 'react';
import { useRouter } from 'next/navigation';
import { Eye, EyeOff, Mail, Lock, User, Phone, ArrowRight } from 'lucide-react';
import { createWorkspaceOwner, createInvitedUser } from '@/lib/api/core';
import { useTheme } from '@/contexts/themecontext';
import Link from 'next/link';

interface RegistrationFormProps {
  type: 'owner' | 'member';
  token?: string;
  email?: string;
}

export default function RegistrationForm({ type, token, email }: RegistrationFormProps) {
  const router = useRouter();
  const { theme } = useTheme();
  const [showPassword, setShowPassword] = useState(false);
  const [formData, setFormData] = useState({
    email: email || '',
    password: '',
    confirmPassword: '',
    name: '',
    phone_number: '',
  });
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);

  const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setFormData(prev => ({
      ...prev,
      [e.target.name]: e.target.value
    }));
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    setError(null);

    if (formData.password !== formData.confirmPassword) {
      setError("Les mots de passe ne correspondent pas");
      return;
    }

    setIsLoading(true);

    try {
      if (type === 'owner') {
        await createWorkspaceOwner(formData);
        router.push('/login');
      }

      if (type === 'member') {
        if (!token) {
          throw new Error('Le jeton est requis pour l\'inscription des membres');
        }
        const response = await createInvitedUser({ ...formData, token });
        router.push(`/login?workspace_id=${response.workspace_id}&email=${response.user.email}`);
      }
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Échec de l\'inscription');
    } finally {
      setIsLoading(false);
    }
  };

  return (
    <form onSubmit={handleSubmit} className="space-y-6">
      {error && (
        <div className={`p-4 rounded-xl ${theme === 'dark' ? 'bg-red-900/50 text-red-300' : 'bg-red-100 text-red-600'} backdrop-blur-xl`}>
          {error}
        </div>
      )}

      <div className="space-y-4">
        {/* Name Field */}
        <div>
          <label htmlFor="name" className={`block text-sm font-medium ${theme === 'dark' ? 'text-gray-300' : 'text-gray-700'} mb-2`}>
            Nom complet
          </label>
          <div className="relative">
            <User className={`absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
            <input
              id="name"
              name="name"
              type="text"
              required
              value={formData.name}
              onChange={handleChange}
              className={`w-full pl-11 pr-4 py-3 rounded-xl ${
                theme === 'dark' 
                  ? 'bg-gray-700/50 text-white placeholder-gray-400 focus:ring-blue-500' 
                  : 'bg-gray-50/50 text-gray-900 placeholder-gray-500 focus:ring-blue-500'
              } border-none focus:ring-2 transition-all duration-300`}
              placeholder="Entrez votre nom complet"
            />
          </div>
        </div>

        {/* Email Field */}
        <div>
          <label htmlFor="email" className={`block text-sm font-medium ${theme === 'dark' ? 'text-gray-300' : 'text-gray-700'} mb-2`}>
            Adresse email
          </label>
          <div className="relative">
            <Mail className={`absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
            <input
              id="email"
              name="email"
              type="email"
              autoComplete="email"
              required
              value={formData.email}
              onChange={handleChange}
              disabled={type === 'member' && !!email}
              className={`w-full pl-11 pr-4 py-3 rounded-xl ${
                theme === 'dark' 
                  ? 'bg-gray-700/50 text-white placeholder-gray-400 focus:ring-blue-500' 
                  : 'bg-gray-50/50 text-gray-900 placeholder-gray-500 focus:ring-blue-500'
              } border-none focus:ring-2 transition-all duration-300 disabled:opacity-50`}
              placeholder="vous@exemple.com"
            />
          </div>
        </div>

        {/* Password Field */}
        <div>
          <label htmlFor="password" className={`block text-sm font-medium ${theme === 'dark' ? 'text-gray-300' : 'text-gray-700'} mb-2`}>
            Mot de passe
          </label>
          <div className="relative">
            <Lock className={`absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
            <input
              id="password"
              name="password"
              type={showPassword ? 'text' : 'password'}
              required
              value={formData.password}
              onChange={handleChange}
              className={`w-full pl-11 pr-11 py-3 rounded-xl ${
                theme === 'dark' 
                  ? 'bg-gray-700/50 text-white placeholder-gray-400 focus:ring-blue-500' 
                  : 'bg-gray-50/50 text-gray-900 placeholder-gray-500 focus:ring-blue-500'
              } border-none focus:ring-2 transition-all duration-300`}
              placeholder="Créez un mot de passe"
            />
            <button
              type="button"
              onClick={() => setShowPassword(!showPassword)}
              className={`absolute right-3 top-1/2 -translate-y-1/2 p-1 rounded-lg ${
                theme === 'dark' ? 'text-gray-400 hover:text-gray-300 hover:bg-gray-600/50' : 'text-gray-600 hover:text-gray-900 hover:bg-gray-200/50'
              } transition-all duration-300`}
            >
              {showPassword ? <EyeOff className="w-5 h-5" /> : <Eye className="w-5 h-5" />}
            </button>
          </div>
        </div>

        {/* Confirm Password Field */}
        <div>
          <label htmlFor="confirmPassword" className={`block text-sm font-medium ${theme === 'dark' ? 'text-gray-300' : 'text-gray-700'} mb-2`}>
            Confirmez le mot de passe
          </label>
          <div className="relative">
            <Lock className={`absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
            <input
              id="confirmPassword"
              name="confirmPassword"
              type="password"
              required
              value={formData.confirmPassword}
              onChange={handleChange}
              className={`w-full pl-11 pr-4 py-3 rounded-xl ${
                theme === 'dark' 
                  ? 'bg-gray-700/50 text-white placeholder-gray-400 focus:ring-blue-500' 
                  : 'bg-gray-50/50 text-gray-900 placeholder-gray-500 focus:ring-blue-500'
              } border-none focus:ring-2 transition-all duration-300`}
              placeholder="Confirmez votre mot de passe"
            />
          </div>
        </div>

        {/* Phone Number Field */}
        <div>
          <label htmlFor="phone_number" className={`block text-sm font-medium ${theme === 'dark' ? 'text-gray-300' : 'text-gray-700'} mb-2`}>
            Numéro de téléphone
          </label>
          <div className="relative">
            <Phone className={`absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 ${theme === 'dark' ? 'text-gray-400' : 'text-gray-500'}`} />
            <input
              id="phone_number"
              name="phone_number"
              type="tel"
              value={formData.phone_number}
              onChange={handleChange}
              className={`w-full pl-11 pr-4 py-3 rounded-xl ${
                theme === 'dark' 
                  ? 'bg-gray-700/50 text-white placeholder-gray-400 focus:ring-blue-500' 
                  : 'bg-gray-50/50 text-gray-900 placeholder-gray-500 focus:ring-blue-500'
              } border-none focus:ring-2 transition-all duration-300`}
              placeholder="Entrez votre numéro de téléphone"
            />
          </div>
        </div>
      </div>

      <button
        type="submit"
        disabled={isLoading}
        className={`w-full flex items-center justify-center px-4 py-3 rounded-xl bg-blue-500 text-white font-medium 
          ${isLoading ? 'opacity-70 cursor-not-allowed' : 'hover:bg-blue-600 hover:shadow-lg hover:-translate-y-0.5'} 
          transition-all duration-300 mt-6`}
      >
        {isLoading ? (
          <div className="w-5 h-5 border-2 border-white border-t-transparent rounded-full animate-spin" />
        ) : (
          <>
            <span>Créer un compte</span>
            <ArrowRight className="w-5 h-5 ml-2 transform group-hover:translate-x-1 transition-transform duration-300" />
          </>
        )}
      </button>

      {type === 'owner' && (
        <p className={`mt-8 text-center text-sm ${theme === 'dark' ? 'text-gray-400' : 'text-gray-600'}`}>
          Vous avez déjà un compte ?{' '}
          <Link
            href="/login"
            className="font-medium text-blue-500 hover:text-blue-400 transition-colors duration-300 hover:underline"
          >
            Se connecter
          </Link>
        </p>
      )}
    </form>
  );
}