import { RegisterOwner, User, InviteData, InviteToken, InvitedUser, UserMe } from '@/types/auth';
import { config } from '@/config';


const API_BASE_URL = `${config.apiCoreUrl}`

// Helper function to handle API errors
const handleApiError = (error: unknown, customMessage: string): never => {
  console.error(`${customMessage}:`, error);
  if (error instanceof Response) {
    throw new Error(`${customMessage} (Status: ${error.status})`);
  }
  throw new Error(customMessage);
};

// Helper function to make authenticated requests
const authenticatedRequest = async (endpoint: string, options: RequestInit = {}): Promise<Response> => {
  const token = localStorage.getItem('token');
  if (!token) {
    throw new Error('No authentication token found');
  }

  const response = await fetch(`${API_BASE_URL}${endpoint}`, {
    ...options,
    headers: {
      ...options.headers,
      'Authorization': `Bearer ${token}`,
      'Content-Type': 'application/json',
    },
  });

  if (!response.ok) {
    throw response;
  }

  return response;
};

export async function createWorkspaceOwner(data: RegisterOwner): Promise<User> {
  try {
    const response = await fetch(`${API_BASE_URL}/workspaces/owner`, {
      method: 'PUT',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify(data),
    });

    if (!response.ok) {
      throw response;
    }

    return response.json();
  } catch (error) {
    return handleApiError(error, 'Failed to create workspace owner');
  }
}

export async function createWorkspace(data: { name: string }): Promise<{ id: string }> {
  try {
    const response = await authenticatedRequest('/workspaces', {
      method: 'POST',
      body: JSON.stringify(data),
    });

    return response.json();
  } catch (error) {
    return handleApiError(error, 'Failed to create workspace');
  }
}

export async function applyUserToWorkspace(data: { workspace_id: string; role: string }): Promise<void> {
  try {
    await authenticatedRequest('/users/workspaces', {
      method: 'POST',
      body: JSON.stringify(data),
    });
  } catch (error) {
    return handleApiError(error, 'Failed to apply user to workspace');
  }
}

export async function createInvitedUser(data: RegisterOwner & { token: string }): Promise<InvitedUser> {
  try {
    const body = {
      email: data.email,
      name: data.name,
      password: data.password,
      phone_number: data.phone_number,
      token: data.token
    };

    const response = await fetch(`${API_BASE_URL}/workspaces/invite`, {
      method: 'POST',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify(body),
    });

    if (!response.ok) {
      throw response;
    }

    return response.json();
  } catch (error) {
    return handleApiError(error, 'Failed to accept invitation');
  }
}

export async function inviteUser(data: InviteData): Promise<{ token: string }> {
  try {
    const response = await authenticatedRequest('/users/invite', {
      method: 'POST',
      body: JSON.stringify(data),
    });

    return response.json();
  } catch (error) {
    return handleApiError(error, 'Failed to invite user');
  }
}

export async function validateInviteToken(token: string): Promise<InviteToken> {
  try {
    const response = await fetch(`${API_BASE_URL}/workspaces/invite/validate?token=${token}`, {
      method: 'GET',
      headers: { 'Content-Type': 'application/json' },
    });

    if (!response.ok) {
      throw response;
    }

    return response.json();
  } catch (error) {
    return handleApiError(error, 'Failed to validate invite token');
  }
}

export async function login(data: { email: string; password: string }): Promise<{ token: string }> {

  const loginUrl = `${API_BASE_URL}/auth/login`;
  console.log(`Attempting login at: ${loginUrl}`);

  try {
    const response = await fetch(loginUrl, {
      method: 'POST',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify(data),
    });

    if (!response.ok) {
      throw response;
    }

    return response.json();
  } catch (error) {
    return handleApiError(error, 'Failed to login');
  }
}

export async function userMe(): Promise<UserMe> {
  try {
    const response = await authenticatedRequest('/users/me');
    return response.json();
  } catch (error) {
    return handleApiError(error, 'Failed to fetch user data');
  }
}

export interface Profile {
  id: string;
  name: string;
  workspace_id: string;
  created_at: string;
  socials?: Social[];
}

export interface Social {
  id: string;
  type: string;
  identifier: string;
  profile_id: string;
  last_sync: string;
}

export async function getProfilesByWorkspace(workspaceId: string): Promise<Profile[]> {
  try {
    const response = await authenticatedRequest(`/profiles/workspaces?workspaceID=${workspaceId}`);
    return response.json();
  } catch (error) {
    return handleApiError(error, 'Failed to fetch profiles');
  }
}

export async function createProfile(data: { 
  name: string; 
  workspace_id: string;
  socials?: { type: string; identifier: string; }[];
}): Promise<Profile> {
  try {
    const response = await authenticatedRequest('/profiles', {
      method: 'POST',
      body: JSON.stringify(data),
    });
    return response.json();
  } catch (error) {
    return handleApiError(error, 'Failed to create profile');
  }
}

export async function updateProfile(profileId: string, data: { name: string }): Promise<Profile> {
  try {
    const response = await authenticatedRequest(`/profiles/${profileId}`, {
      method: 'PUT',
      body: JSON.stringify(data),
    });
    return response.json();
  } catch (error) {
    return handleApiError(error, 'Failed to update profile');
  }
}

export async function deleteProfile(profileId: string): Promise<void> {
  try {
    await authenticatedRequest(`/profiles/${profileId}`, {
      method: 'DELETE',
    });
  } catch (error) {
    return handleApiError(error, 'Failed to delete profile');
  }
}
